
RELEASE_VERSION='0.0.423284718'
BUILD_DATE='Mon Dec  6 10:19:02 UTC 2021'
BUILD_MACHINE_INFO='Linux runner-t4krtqay-project-28359933-concurrent-0c87n8 5.4.129-62.227.amzn2.x86_64 #1 SMP Wed Jul 7 00:08:43 UTC 2021 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='1852878510'
GIT_COMMIT_SHA='25a84b9ce59080a55c39acec59d9a690f9512410'
GIT_BRANCH='main'
